[][src]Enum tower_hyper::client::ConnectError

pub enum ConnectError<T> {
    Connect(T),
    Handshake(Error),
    SpawnError,
}

The error produced from creating a connection

Variants

Connect(T)

An error occurred while attempting to establish the connection.

Handshake(Error)

An error occurred while performing hyper's handshake.

SpawnError

An error occurred attempting to spawn the connect task on the provided executor.