[−][src]Struct tower_hyper::client::Connect
Creates a hyper connection
This accepts a hyper::client::conn::Builder and provides
a MakeService implementation to create connections from some
target A
Methods
impl<A, B, C> Connect<A, B, C, DefaultExecutor> where
C: HttpMakeConnection<A>,
B: HttpBody,
C::Connection: Send + 'static, [src]
C: HttpMakeConnection<A>,
B: HttpBody,
C::Connection: Send + 'static,
pub fn new(inner: C) -> Self[src]
Create a new Connect.
The C argument is used to obtain new session layer instances
(AsyncRead + AsyncWrite). For each new client service returned, a
Service is returned that can be driven by poll_service and to send
requests via call.
pub fn with_builder(inner: C, builder: Builder) -> Self[src]
Create a new Connect with a builder.
impl<A, B, C, E> Connect<A, B, C, E> where
C: HttpMakeConnection<A>,
B: HttpBody,
C::Connection: Send + 'static, [src]
C: HttpMakeConnection<A>,
B: HttpBody,
C::Connection: Send + 'static,
pub fn with_executor(inner: C, builder: Builder, exec: E) -> Self[src]
Create a new Connect.
The C argument is used to obtain new session layer instances
(AsyncRead + AsyncWrite). For each new client service returned, a
Service is returned that can be driven by poll_service and to send
requests via call.
The E argument is the executor that the background task for the connection
will be spawned on.