[−][src]Struct tower_hyper::server::Http
A lower-level configuration of the HTTP protocol.
This structure is used to configure options for an HTTP server connection.
If you don't have need to manage connections yourself, consider using the higher-level Server API.
Methods
impl Http<Exec>[src]
pub fn new() -> Http<Exec>[src]
Creates a new instance of the HTTP protocol, ready to spawn a server or start accepting connections.
impl<E> Http<E>[src]
pub fn http1_only(&mut self, val: bool) -> &mut Http<E>[src]
Sets whether HTTP1 is required.
Default is false
pub fn http1_half_close(&mut self, val: bool) -> &mut Http<E>[src]
Set whether HTTP/1 connections should support half-closures.
Clients can chose to shutdown their write-side while waiting
for the server to respond. Setting this to false will
automatically close any connection immediately if read
detects an EOF.
Default is true.
pub fn http1_writev(&mut self, val: bool) -> &mut Http<E>[src]
Set whether HTTP/1 connections should try to use vectored writes, or always flatten into a single buffer.
Note that setting this to false may mean more copies of body data, but may also improve performance when an IO transport doesn't support vectored writes well, such as most TLS implementations.
Default is true.
pub fn http2_only(&mut self, val: bool) -> &mut Http<E>[src]
Sets whether HTTP2 is required.
Default is false
pub fn http2_initial_stream_window_size<impl Into[src]
Sets the SETTINGS_INITIAL_WINDOW_SIZE option for HTTP2
stream-level flow control.
Default is 65,535
pub fn http2_initial_connection_window_size<impl Into>>(
&mut self,
sz: impl Into >
) -> &mut Http<E> where
impl Into>: Into<Option<u32>>, [src]
&mut self,
sz: impl Into
) -> &mut Http<E> where
impl Into
Sets the max connection-level flow control for HTTP2
Default is 65,535
pub fn http2_max_concurrent_streams<impl Into>>(
&mut self,
max: impl Into >
) -> &mut Http<E> where
impl Into>: Into<Option<u32>>, [src]
&mut self,
max: impl Into
) -> &mut Http<E> where
impl Into
Sets the SETTINGS_MAX_CONCURRENT_STREAMS option for HTTP2
connections.
Default is no limit (None).
pub fn keep_alive(&mut self, val: bool) -> &mut Http<E>[src]
Enables or disables HTTP keep-alive.
Default is true.
pub fn max_buf_size(&mut self, max: usize) -> &mut Http<E>[src]
Set the maximum buffer size for the connection.
Default is ~400kb.
Panics
The minimum value allowed is 8192. This method panics if the passed max is less than the minimum.
pub fn pipeline_flush(&mut self, enabled: bool) -> &mut Http<E>[src]
Aggregates flushes to better support pipelined responses.
Experimental, may have bugs.
Default is false.
pub fn with_executor<E2>(self, exec: E2) -> Http<E2>[src]
Set the executor used to spawn background tasks.
Default uses implicit default (like tokio::spawn).
pub fn serve_connection<S, I, Bd>(
&self,
io: I,
service: S
) -> Connection<I, S, E> where
Bd: Payload,
E: H2Exec<<S as Service>::Future, Bd>,
I: AsyncRead + AsyncWrite,
S: Service<ReqBody = Body, ResBody = Bd>,
<S as Service>::Error: Into<Box<dyn Error + 'static + Sync + Send>>, [src]
&self,
io: I,
service: S
) -> Connection<I, S, E> where
Bd: Payload,
E: H2Exec<<S as Service>::Future, Bd>,
I: AsyncRead + AsyncWrite,
S: Service<ReqBody = Body, ResBody = Bd>,
<S as Service>::Error: Into<Box<dyn Error + 'static + Sync + Send>>,
Bind a connection together with a Service.
This returns a Future that must be polled in order for HTTP to be driven on the connection.
Example
let http = Http::new(); let conn = http.serve_connection(some_io, some_service); let fut = conn.map_err(|e| { eprintln!("server connection error: {}", e); }); hyper::rt::spawn(fut);
pub fn serve_addr<S, Bd>(
&self,
addr: &SocketAddr,
make_service: S
) -> Result<Serve<AddrIncoming, S, E>, Error> where
Bd: Payload,
E: H2Exec<<<S as MakeServiceRef<AddrStream>>::Service as Service>::Future, Bd>,
S: MakeServiceRef<AddrStream, ReqBody = Body, ResBody = Bd>,
<S as MakeServiceRef<AddrStream>>::Error: Into<Box<dyn Error + 'static + Sync + Send>>, [src]
&self,
addr: &SocketAddr,
make_service: S
) -> Result<Serve<AddrIncoming, S, E>, Error> where
Bd: Payload,
E: H2Exec<<<S as MakeServiceRef<AddrStream>>::Service as Service>::Future, Bd>,
S: MakeServiceRef<AddrStream, ReqBody = Body, ResBody = Bd>,
<S as MakeServiceRef<AddrStream>>::Error: Into<Box<dyn Error + 'static + Sync + Send>>,
Bind the provided addr with the default Handle and return Serve.
This method will bind the addr provided with a new TCP listener ready
to accept connections. Each connection will be processed with the
make_service object provided, creating a new service per
connection.
pub fn serve_addr_handle<S, Bd>(
&self,
addr: &SocketAddr,
handle: &Handle,
make_service: S
) -> Result<Serve<AddrIncoming, S, E>, Error> where
Bd: Payload,
E: H2Exec<<<S as MakeServiceRef<AddrStream>>::Service as Service>::Future, Bd>,
S: MakeServiceRef<AddrStream, ReqBody = Body, ResBody = Bd>,
<S as MakeServiceRef<AddrStream>>::Error: Into<Box<dyn Error + 'static + Sync + Send>>, [src]
&self,
addr: &SocketAddr,
handle: &Handle,
make_service: S
) -> Result<Serve<AddrIncoming, S, E>, Error> where
Bd: Payload,
E: H2Exec<<<S as MakeServiceRef<AddrStream>>::Service as Service>::Future, Bd>,
S: MakeServiceRef<AddrStream, ReqBody = Body, ResBody = Bd>,
<S as MakeServiceRef<AddrStream>>::Error: Into<Box<dyn Error + 'static + Sync + Send>>,
Bind the provided addr with the Handle and return a Serve
This method will bind the addr provided with a new TCP listener ready
to accept connections. Each connection will be processed with the
make_service object provided, creating a new service per
connection.
pub fn serve_incoming<I, S, Bd>(
&self,
incoming: I,
make_service: S
) -> Serve<I, S, E> where
Bd: Payload,
E: H2Exec<<<S as MakeServiceRef<<I as Stream>::Item>>::Service as Service>::Future, Bd>,
I: Stream,
S: MakeServiceRef<<I as Stream>::Item, ReqBody = Body, ResBody = Bd>,
<I as Stream>::Error: Into<Box<dyn Error + 'static + Sync + Send>>,
<I as Stream>::Item: AsyncRead,
<I as Stream>::Item: AsyncWrite,
<S as MakeServiceRef<<I as Stream>::Item>>::Error: Into<Box<dyn Error + 'static + Sync + Send>>, [src]
&self,
incoming: I,
make_service: S
) -> Serve<I, S, E> where
Bd: Payload,
E: H2Exec<<<S as MakeServiceRef<<I as Stream>::Item>>::Service as Service>::Future, Bd>,
I: Stream,
S: MakeServiceRef<<I as Stream>::Item, ReqBody = Body, ResBody = Bd>,
<I as Stream>::Error: Into<Box<dyn Error + 'static + Sync + Send>>,
<I as Stream>::Item: AsyncRead,
<I as Stream>::Item: AsyncWrite,
<S as MakeServiceRef<<I as Stream>::Item>>::Error: Into<Box<dyn Error + 'static + Sync + Send>>,
Bind the provided stream of incoming IO objects with a MakeService.