[−][src]Struct tower_hyper::server::Server
Server implemenation for hyper
Methods
impl<S, B> Server<S, B> where
S: MakeService<(), Request<Body>, Response = Response<B>> + Send + 'static,
S::MakeError: Into<Box<dyn Error + Send + Sync>>,
S::Error: Into<Box<dyn Error + Send + Sync>>,
S::Future: Send,
S::Service: Service<Request<Body>> + Send,
<S::Service as Service<Request<Body>>>::Future: Send + 'static,
B: HttpBody + Send + 'static,
B::Data: Send + 'static,
B::Error: Into<Box<dyn Error + Send + Sync>> + 'static, [src]
S: MakeService<(), Request<Body>, Response = Response<B>> + Send + 'static,
S::MakeError: Into<Box<dyn Error + Send + Sync>>,
S::Error: Into<Box<dyn Error + Send + Sync>>,
S::Future: Send,
S::Service: Service<Request<Body>> + Send,
<S::Service as Service<Request<Body>>>::Future: Send + 'static,
B: HttpBody + Send + 'static,
B::Data: Send + 'static,
B::Error: Into<Box<dyn Error + Send + Sync>> + 'static,
pub fn new(maker: S) -> Self[src]
Create a new server from a MakeService
pub fn serve<I>(&mut self, io: I) -> Serve<S::MakeError> where
I: AsyncRead + AsyncWrite + Send + 'static, [src]
I: AsyncRead + AsyncWrite + Send + 'static,
Serve the io stream via default hyper http settings
pub fn serve_with<I>(&mut self, io: I, http: Http) -> Serve<S::MakeError> where
I: AsyncRead + AsyncWrite + Send + 'static, [src]
I: AsyncRead + AsyncWrite + Send + 'static,
Serve the io stream via the provided hyper http settings